@@ -4,7 +4,7 @@
  * Start Date:  Thu Dec 28 17:29:05 1995
  * Project:     INN (innfeed)
  * File:        host.c
- * RCSId:       $Id: host.c,v 1.14 1997/05/12 02:52:57 scrappy Exp $
+ * RCSId:       $Id: host.c,v 1.16 1997/05/22 02:26:23 scrappy Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: host.c,v 1.14 1997/05/12 02:52:57 scrappy Exp $" ;
+static const char *rcsid = "$Id: host.c,v 1.16 1997/05/22 02:26:23 scrappy Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -1146,7 +1146,7 @@ void printHostInfo (Host host, FILE *fp, u_int indentAmt)
            100.0 * host->blQuartile[3] / cnt) ;
   fprintf (fp,"%s      percentage of the time full : %.1f\n", indent,
            100.0 * host->blFull / cnt) ;
-  fprintf (fp,"%s      number of samples : %.1f\n", indent, host->blCount) ;
+  fprintf (fp,"%s      number of samples : %u\n", indent, host->blCount) ;
 
   fprintf (fp,"%s    firstConnectTime : %s",indent,
            ctime (&host->firstConnectTime));
@@ -2079,7 +2079,7 @@ void hostSetStatusFile (const char *filename)
   
   if (filename == NULL)
     die ("Can't set status file name with a NULL filename\n") ;
-  else if (*filename == NULL)
+  else if (*filename == '\0')
     die ("Can't set status file name with a empty string\n") ;
 
   if (*filename == '/')
@@ -2262,7 +2262,7 @@ static void hostDetails (scope *s,
               NO_CHECK_HIGH, rv, name, NO_CHECK_LOW, *lowFilter);
       rv = 100.0 ;
     }
-  *highFilter = rv / 10.0 ;
+  *highFilter = rv * (FILTERVALUE/100.0) ;
       
 
   if (!getInteger (s,PORT_NUMBER,&iv,INHERIT))
@@ -2655,9 +2655,9 @@ static void hostLogStatus (void)
       fprintf(fp,"         max checks: %-5d               streaming: %s\n",
 	       defaultMaxChecks, (defaultStreaming ? "true" : "false")) ;
       fprintf(fp,"       on threshold: %-2.1f%%                port num: %d\n",
-	       (defaultHighFilter * 10), defaultPortNumber) ;
+	       (defaultHighFilter * 100.0 / FILTERVALUE), defaultPortNumber) ;
       fprintf(fp,"      off threshold: %-2.1f%%\n\n",
-	       (defaultLowFilter * 10)) ;
+	       (defaultLowFilter * 100.0 / FILTERVALUE)) ;
 
       tapeLogGlobalStatus (fp) ;
 
@@ -2745,11 +2745,11 @@ static void hostPrintStatus (Host host, FILE *fp)
 	   host->initialCxns) ;
 
   fprintf (fp, "   missing: %-7ld   on threshold: %-3.1f%%      idle cxns: %d\n",
-	   (long) host->gArtsMissing, (host->lowPassHigh * 10),
+	   (long) host->gArtsMissing, (host->lowPassHigh * 100.0 / FILTERVALUE),
            host->maxConnections - (host->activeCxns + host->sleepingCxns)) ;
 
   fprintf (fp, "  deferred: %-7ld  off threshold: %-3.1f%%       max cxns: %d\n",
-	   (long) host->gArtsDeferred, (host->lowPassLow * 10),
+	   (long) host->gArtsDeferred, (host->lowPassLow * 100.0 / FILTERVALUE),
 	   host->maxConnections) ;
 
   fprintf (fp, "  requeued: %-7ld                         queue length: %-3.1f\n",
